@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'connection'
+require_relative "connection"
 
 module Protocol
 	module HTTP2
@@ -31,7 +31,9 @@ module Protocol
 					send_settings(settings)
 					
 					read_frame do |frame|
-						raise ProtocolError, "First frame must be #{SettingsFrame}, but got #{frame.class}" unless frame.is_a? SettingsFrame
+						unless frame.is_a? SettingsFrame
+							raise ProtocolError, "First frame must be #{SettingsFrame}, but got #{frame.class}"
+						end
 					end
 				else
 					raise ProtocolError, "Cannot read connection preface in state #{@state}"
